@@ -78,23 +78,12 @@ def post_json_with_header(url, payload, headers):
     """ Post URL as json string.
         Returns: json string"""
 
-    try:
-        pprint(url)
-        pprint(headers)
-        lines = subprocess.run(["curl", "-X", "POST", "https://circleci.com/api/v2/project/github/ortelius/store-hipster-app-qa3-windows/pipeline", "-H", 'Accept: application/json', "-H", 'Circle-Token:2b88069948ec829dad359753d48de0b801f2d933', "-v" ], check=False, stdout=subprocess.PIPE).stdout.decode('utf-8').split("\n")
-        for line in lines:
-            print(line)
-
-        res = requests.post(url, data=payload, headers=headers)
-        pprint(res)
-        if (res is None):
-            return None
-        if (res.status_code != 200 and res.status_code != 201):
-            return None
-        return res.json()
-    except requests.exceptions.ConnectionError as conn_error:
-        print(str(conn_error))
-    return None
+    pprint(url)
+    pprint(headers)
+    lines = subprocess.run(["curl", "-X", "POST", "https://circleci.com/api/v2/project/github/ortelius/store-hipster-app-qa3-windows/pipeline", "-H", 'Accept: application/json', "-H", 'Circle-Token:2b88069948ec829dad359753d48de0b801f2d933', "-v" ], check=False, stdout=subprocess.PIPE).stdout.decode('utf-8').split("\n")
+    for line in lines:
+        print(line)
+    return lines
 
 def is_empty(my_string):
     """Is the string empty"""
